==> kubernetes-model-autoscaling-5.2.1-sources.jar: io/fabric8/kubernetes/api/model/autoscaling/v2beta2/ContainerResourceMetricStatusBuilder.java <==
package io.fabric8.kubernetes.api.model.autoscaling.v2beta2;

import io.fabric8.kubernetes.api.builder.VisitableBuilder;
import java.lang.Object;
import java.lang.Boolean;

public class ContainerResourceMetricStatusBuilder extends io.fabric8.kubernetes.api.model.autoscaling.v2beta2.ContainerResourceMetricStatusFluentImpl<io.fabric8.kubernetes.api.model.autoscaling.v2beta2.ContainerResourceMetricStatusBuilder> implements VisitableBuilder<io.fabric8.kubernetes.api.model.autoscaling.v2beta2.ContainerResourceMetricStatus,io.fabric8.kubernetes.api.model.autoscaling.v2beta2.ContainerResourceMetricStatusBuilder> {

    io.fabric8.kubernetes.api.model.autoscaling.v2beta2.ContainerResourceMetricStatusFluent<?> fluent;
    Boolean validationEnabled;

    public ContainerResourceMetricStatusBuilder() {
        this(true);
    }

    public ContainerResourceMetricStatusBuilder(Boolean validationEnabled) {
        this(new ContainerResourceMetricStatus(), validationEnabled);
    }

    public ContainerResourceMetricStatusBuilder(io.fabric8.kubernetes.api.model.autoscaling.v2beta2.ContainerResourceMetricStatusFluent<?> fluent) {
        this(fluent, true);
    }

    public ContainerResourceMetricStatusBuilder(io.fabric8.kubernetes.api.model.autoscaling.v2beta2.ContainerResourceMetricStatusFluent<?> fluent,Boolean validationEnabled) {
        this(fluent, new ContainerResourceMetricStatus(), validationEnabled);
    }

    public ContainerResourceMetricStatusBuilder(io.fabric8.kubernetes.api.model.autoscaling.v2beta2.ContainerResourceMetricStatusFluent<?> fluent,io.fabric8.kubernetes.api.model.autoscaling.v2beta2.ContainerResourceMetricStatus instance) {
        this(fluent, instance, true);
    }

    public ContainerResourceMetricStatusBuilder(io.fabric8.kubernetes.api.model.autoscaling.v2beta2.ContainerResourceMetricStatusFluent<?> fluent,io.fabric8.kubernetes.api.model.autoscaling.v2beta2.ContainerResourceMetricStatus instance,Boolean validationEnabled) {
        this.fluent = fluent; 
        fluent.withContainer(instance.getContainer()); 
        fluent.withCurrent(instance.getCurrent()); 
        fluent.withName(instance.getName()); 
        this.validationEnabled = validationEnabled; 
    }

    public ContainerResourceMetricStatusBuilder(io.fabric8.kubernetes.api.model.autoscaling.v2beta2.ContainerResourceMetricStatus instance) {
        this(instance,true);
    }

    public ContainerResourceMetricStatusBuilder(io.fabric8.kubernetes.api.model.autoscaling.v2beta2.ContainerResourceMetricStatus instance,Boolean validationEnabled) {
        this.fluent = this; 
        this.withContainer(instance.getContainer()); 
        this.withCurrent(instance.getCurrent()); 
        this.withName(instance.getName()); 
        this.validationEnabled = validationEnabled; 
    }

    public io.fabric8.kubernetes.api.model.autoscaling.v2beta2.ContainerResourceMetricStatus build() {
        ContainerResourceMetricStatus buildable = new ContainerResourceMetricStatus(fluent.getContainer(),fluent.getCurrent(),fluent.getName());
        return buildable;
    }

    public boolean equals(Object o) {
        if (this == o) return true;
        if (o == null || getClass() != o.getClass()) return false;
        if (!super.equals(o)) return false;
        ContainerResourceMetricStatusBuilder that = (ContainerResourceMetricStatusBuilder) o;
        if (fluent != null &&fluent != this ? !fluent.equals(that.fluent) :that.fluent != null &&fluent != this ) return false;
        
        if (validationEnabled != null ? !validationEnabled.equals(that.validationEnabled) :that.validationEnabled != null) return false;
        return true;
    }

    public int hashCode() {
        return java.util.Objects.hash(fluent,  validationEnabled,  super.hashCode());
    }

}

==> kubernetes-model-autoscaling-5.3.1-sources.jar: io/fabric8/kubernetes/api/model/autoscaling/v2beta2/ContainerResourceMetricStatusBuilder.java <==
package io.fabric8.kubernetes.api.model.autoscaling.v2beta2;

import io.fabric8.kubernetes.api.builder.VisitableBuilder;
import java.lang.Object;
import java.lang.Boolean;

public class ContainerResourceMetricStatusBuilder extends io.fabric8.kubernetes.api.model.autoscaling.v2beta2.ContainerResourceMetricStatusFluentImpl<io.fabric8.kubernetes.api.model.autoscaling.v2beta2.ContainerResourceMetricStatusBuilder> implements io.fabric8.kubernetes.api.builder.VisitableBuilder<io.fabric8.kubernetes.api.model.autoscaling.v2beta2.ContainerResourceMetricStatus,io.fabric8.kubernetes.api.model.autoscaling.v2beta2.ContainerResourceMetricStatusBuilder> {

    io.fabric8.kubernetes.api.model.autoscaling.v2beta2.ContainerResourceMetricStatusFluent<?> fluent;
    Boolean validationEnabled;

    public ContainerResourceMetricStatusBuilder() {
        this(true);
    }

    public ContainerResourceMetricStatusBuilder(Boolean validationEnabled) {
        this(new ContainerResourceMetricStatus(), validationEnabled);
    }

    public ContainerResourceMetricStatusBuilder(io.fabric8.kubernetes.api.model.autoscaling.v2beta2.ContainerResourceMetricStatusFluent<?> fluent) {
        this(fluent, true);
    }

    public ContainerResourceMetricStatusBuilder(io.fabric8.kubernetes.api.model.autoscaling.v2beta2.ContainerResourceMetricStatusFluent<?> fluent,Boolean validationEnabled) {
        this(fluent, new ContainerResourceMetricStatus(), validationEnabled);
    }

    public ContainerResourceMetricStatusBuilder(io.fabric8.kubernetes.api.model.autoscaling.v2beta2.ContainerResourceMetricStatusFluent<?> fluent,io.fabric8.kubernetes.api.model.autoscaling.v2beta2.ContainerResourceMetricStatus instance) {
        this(fluent, instance, true);
    }

    public ContainerResourceMetricStatusBuilder(io.fabric8.kubernetes.api.model.autoscaling.v2beta2.ContainerResourceMetricStatusFluent<?> fluent,io.fabric8.kubernetes.api.model.autoscaling.v2beta2.ContainerResourceMetricStatus instance,Boolean validationEnabled) {
        this.fluent = fluent; 
        fluent.withContainer(instance.getContainer()); 
        fluent.withCurrent(instance.getCurrent()); 
        fluent.withName(instance.getName()); 
        this.validationEnabled = validationEnabled; 
    }

    public ContainerResourceMetricStatusBuilder(io.fabric8.kubernetes.api.model.autoscaling.v2beta2.ContainerResourceMetricStatus instance) {
        this(instance,true);
    }

    public ContainerResourceMetricStatusBuilder(io.fabric8.kubernetes.api.model.autoscaling.v2beta2.ContainerResourceMetricStatus instance,Boolean validationEnabled) {
        this.fluent = this; 
        this.withContainer(instance.getContainer()); 
        this.withCurrent(instance.getCurrent()); 
        this.withName(instance.getName()); 
        this.validationEnabled = validationEnabled; 
    }

    public io.fabric8.kubernetes.api.model.autoscaling.v2beta2.ContainerResourceMetricStatus build() {
        ContainerResourceMetricStatus buildable = new ContainerResourceMetricStatus(fluent.getContainer(),fluent.getCurrent(),fluent.getName());
        return buildable;
    }

    public boolean equals(Object o) {
        if (this == o) return true;
        if (o == null || getClass() != o.getClass()) return false;
        if (!super.equals(o)) return false;
        ContainerResourceMetricStatusBuilder that = (ContainerResourceMetricStatusBuilder) o;
        if (fluent != null &&fluent != this ? !fluent.equals(that.fluent) :that.fluent != null &&fluent != this ) return false;
        
        if (validationEnabled != null ? !validationEnabled.equals(that.validationEnabled) :that.validationEnabled != null) return false;
        return true;
    }

    public int hashCode() {
        return java.util.Objects.hash(fluent,  validationEnabled,  super.hashCode());
    }

}
